==> schema_widget-1.0.0.tar.gz: lib/parser/type/snack_bar_behavior_schema_parser.dart <==
// Copyright (c) 2020 Legytma Soluções Inteligentes (https://legytma.com.br).
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import 'package:flutter/material.dart';
import 'package:json_schema/json_schema.dart';

import '../../schema_widget.dart';

/// Schema parser from [String] to [SnackBarBehavior]
///
/// Created by Windol <windol@legytma.com.br> at 23/04/2020.
/// Copyright (c) 2020 Legytma Soluções Inteligentes (https://legytma.com.br). All rights reserved.
@SchemaParser("SnackBarBehavior",
    "https://schema.legytma.com.br/2.0.0/schema/snack_bar_behavior.schema.json")
class SnackBarBehaviorSchemaParser
    extends TypeSchemaParser<SnackBarBehavior, String, SnackBarBehavior> {
  /// Create instance of parser using [JsonSchema] to validate values.
  SnackBarBehaviorSchemaParser([JsonSchema jsonSchema]) : super(jsonSchema);

  @override
  SnackBarBehavior builder(BuildContext buildContext, String value,
      [SnackBarBehavior defaultValue]) {
    switch (value) {
      case 'fixed':
        return SnackBarBehavior.fixed;
      case 'floating':
        return SnackBarBehavior.floating;
      default:
        return defaultValue;
    }
  }
}

==> schema_widget-1.0.0-5.tar.gz: lib/parser/type/snack_bar_behavior_schema_parser.dart <==
// Copyright (c) 2020 Legytma Soluções Inteligentes (https://legytma.com.br).
//
//  Licensed under the Apache License, Version 2.0 (the "License");
//  you may not use this file except in compliance with the License.
//  You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import 'package:flutter/material.dart';
import 'package:json_schema/json_schema.dart';

import '../../schema_widget.dart';

/// Schema parser from [String] to [SnackBarBehavior]
///
/// Created by Windol <windol@legytma.com.br> at 23/04/2020.
/// Copyright (c) 2020 Legytma Soluções Inteligentes (https://legytma.com.br). All rights reserved.
@SchemaParser("SnackBarBehavior",
    "https://schema.legytma.com.br/2.0.0/schema/snack_bar_behavior.schema.json")
class SnackBarBehaviorSchemaParser
    extends TypeSchemaParser<SnackBarBehavior, String, SnackBarBehavior> {
  /// Create instance of parser using [JsonSchema] to validate values.
  SnackBarBehaviorSchemaParser(JsonSchema jsonSchema) : super(jsonSchema);

  @override
  SnackBarBehavior builder(BuildContext buildContext, String value,
      [SnackBarBehavior defaultValue]) {
    switch (value) {
      case 'fixed':
        return SnackBarBehavior.fixed;
      case 'floating':
        return SnackBarBehavior.floating;
      default:
        return defaultValue;
    }
  }
}
